@@ -873,7 +873,7 @@ isns_dd_parse_attrs(isns_dd_t *dd, isns_db_t *db,
 			if (next->ia_tag_id != ISNS_TAG_DD_MEMBER_PORTAL_TCP_UDP_PORT)
 				goto invalid;
 			i += 1;
-			/* fallthru to normal case */
+			/* fallthru */
 
 		case ISNS_TAG_DD_MEMBER_PORTAL_INDEX:
 		case ISNS_TAG_DD_MEMBER_ISCSI_INDEX:
@@ -1043,6 +1043,10 @@ isns_dd_add_members(isns_dd_t *dd, isns_db_t *db, isns_dd_t *new_dd)
 			isns_db_insert_limbo(db, obj);
 		mp->ddm_index = obj->ie_index;
 
+		/* Record the fact that the object is a member of
+		   this DD */
+		isns_object_mark_membership(obj, dd->dd_id);
+
 		switch (mp->ddm_type) {
 		case ISNS_DD_MEMBER_ISCSI_NODE:
 			if (isns_object_get_string(obj, ISNS_TAG_ISCSI_NAME, &node_name))
@@ -1079,7 +1083,9 @@ isns_dd_add_members(isns_dd_t *dd, isns_db_t *db, isns_dd_t *new_dd)
  * Remove members from a DD
  */
 int
-isns_dd_remove_members(isns_dd_t *dd, isns_db_t *db, isns_dd_t *temp_dd)
+isns_dd_remove_members(isns_dd_t *dd,
+		__attribute__((unused))isns_db_t *db,
+		isns_dd_t *temp_dd)
 {
 	isns_dd_member_t *mp;
 
@@ -1103,7 +1109,8 @@ isns_dd_remove_members(isns_dd_t *dd, isns_db_t *db, isns_dd_t *temp_dd)
 }
 
 void
-isns_dd_store(isns_db_t *db, const isns_dd_t *dd, int rewrite)
+isns_dd_store(__attribute__((unused))isns_db_t *db,
+		const isns_dd_t *dd, int rewrite)
 {
 	isns_object_t	*obj = dd->dd_object;
 	isns_dd_member_t *member;
@@ -1235,7 +1242,7 @@ isns_dd_get_member_object(isns_db_t *db, const isns_attr_t *key1,
 	isns_object_template_t *tmpl = NULL;
 	isns_object_t	*obj;
 	isns_portal_info_t portal_info;
-	const char	*key_string = NULL;
+	char		*key_string = NULL;
 	uint32_t	key_index = 0;
 
 	switch (key1->ia_tag_id) {
@@ -1279,7 +1286,7 @@ isns_dd_get_member_object(isns_db_t *db, const isns_attr_t *key1,
 			 &query))
 			return NULL;
 
-		key_string = isns_portal_string(&portal_info);
+		key_string = (char *)isns_portal_string(&portal_info);
 		tmpl = &isns_portal_template;
 		break;
 
